@@ -61,6 +61,8 @@ import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPCapabilities;
 import com.openexchange.imap.IMAPFolderStorage;
 import com.openexchange.imap.IMAPProvider;
+import com.openexchange.mail.Protocol;
+import com.openexchange.mail.api.IMailFolderStorageDelegator;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.service.MailService;
 import com.openexchange.mail.utils.MailFolderUtility;
@@ -117,7 +119,7 @@ public final class ImapIdlePushListener implements PushListener, Runnable {
     }
 
     private static volatile Boolean DEBUG_ENABLED;
-    
+
     /**
      * @param debugEnabled the debugEnabled to set
      */
@@ -348,18 +350,20 @@ public final class ImapIdlePushListener implements PushListener, Runnable {
             /*
              * Get access
              */
-            final MailAccess<?, ?> access = mailService.getMailAccess(session, MailAccount.DEFAULT_ID);
-            /*
-             * Check protocol
-             */
-            if (!IMAPProvider.PROTOCOL_IMAP.equals(access.getProvider().getProtocol())) {
-                throw PushExceptionCodes.UNEXPECTED_ERROR.create("Primary mail account is not IMAP!");
-            }
-            /*
-             * Check for IDLE capability
-             */
-            access.connect(false);
+            MailAccess<?, ?> access = null;
             try {
+                access = mailService.getMailAccess(session, MailAccount.DEFAULT_ID);
+                /*
+                 * Check protocol
+                 */
+                final Protocol protocol = access.getProvider().getProtocol();
+                if (null == protocol || (!Protocol.ALL.equals(protocol.getName()) && !IMAPProvider.PROTOCOL_IMAP.equals(protocol))) {
+                    throw PushExceptionCodes.UNEXPECTED_ERROR.create("Primary mail account is not IMAP, but " + (null == protocol ? "is missing." : protocol.getName()));
+                }
+                /*
+                 * Check for IDLE capability
+                 */
+                access.connect(false);
                 final IMAPCapabilities capabilities = (IMAPCapabilities) access.getMailConfig().getCapabilities();
                 if (!capabilities.hasIdle()) {
                     throw PushExceptionCodes.UNEXPECTED_ERROR.create("Primary IMAP account does not support \"IDLE\" capability!");
@@ -375,7 +379,9 @@ public final class ImapIdlePushListener implements PushListener, Runnable {
                 }
                  */
             } finally {
-                access.close(true);
+                if (null != access) {
+                    access.close(true);
+                }
             }
         }
         imapIdleFuture = threadPoolService.submit(ThreadPools.task(this, getClass().getName()));
@@ -498,9 +504,15 @@ public final class ImapIdlePushListener implements PushListener, Runnable {
             mailAccess.connect(false);
             final IMAPFolderStorage istore;
             {
-                final Object fstore = mailAccess.getFolderStorage();
+                Object fstore = mailAccess.getFolderStorage();
                 if (!(fstore instanceof IMAPFolderStorage)) {
-                    throw PushExceptionCodes.UNEXPECTED_ERROR.create("Unknown MAL implementation");
+                    if (!(fstore instanceof IMailFolderStorageDelegator)) {
+                        throw PushExceptionCodes.UNEXPECTED_ERROR.create("Unknown MAL implementation");
+                    }
+                    fstore = ((IMailFolderStorageDelegator) fstore).getDelegateFolderStorage();
+                    if (!(fstore instanceof IMAPFolderStorage)) {
+                        throw PushExceptionCodes.UNEXPECTED_ERROR.create("Unknown MAL implementation");
+                    }
                 }
                 istore = (IMAPFolderStorage) fstore;
             }
@@ -657,7 +669,7 @@ public final class ImapIdlePushListener implements PushListener, Runnable {
 
         /**
          * Initializes a new {@link MissingSessionException}.
-         * 
+         *
          * @param message The message
          */
         public MissingSessionException(final String message) {
